<?php
/**
 * Claremont functions.
 */

if ( ! function_exists( 'claremont_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function claremont_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be added to the /languages/ directory.
		 */
		load_theme_textdomain( 'claremont', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'claremont' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'gallery',
			'caption',
			'comment-list',
			'comment-form',
		) );

		// Support for Custom Logo
		add_theme_support('custom-logo', array(
    		'width'	=> '300',
    		'height'	=> '105',
		) );

		// Enable support for widgets selective refresh
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Support for Gutenberg (5.0+ block editor)
		add_theme_support( 'align-wide' );

	}
	endif; // claremont_setup
add_action( 'after_setup_theme', 'claremont_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function claremont_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'claremont_content_width', 1200 );
}
add_action( 'after_setup_theme', 'claremont_content_width', 0 );

/**
 * Flush out the transients used in claremont_categorized_blog.
 */
function claremont_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'claremont_categories' );
}
add_action( 'edit_category', 'claremont_category_transient_flusher' );
add_action( 'save_post',     'claremont_category_transient_flusher' );

/**
 * Register widget areas.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function claremont_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Primary Sidebar', 'claremont' ),
			'id'            => 'primary-sidebar',
			'description'   => esc_html__( 'The primary sidebar', 'claremont' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Top Left Area', 'claremont' ),
			'id'            => 'home-top-left',
			'description'   => esc_html__( 'The top left area above the page content on the Home Page template', 'claremont' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Top Right Area', 'claremont' ),
			'id'            => 'home-top-right',
			'description'   => esc_html__( 'The top right area above the page content on the Home Page template', 'claremont' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Above Footer', 'claremont' ),
			'id'            => 'home-footer-above',
			'description'   => esc_html__( 'The area above the footer on the Home Page template', 'claremont' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	for ( $i = 1, $n = 4; $i <= $n; $i++ ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Footer Column #', 'claremont' ) . $i,
				'id'            => 'footer-' . $i,
				'description'   => sprintf( esc_html__( 'The #%s column in footer area', 'claremont' ), $i ),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			)
		);
	}
}
add_action( 'widgets_init', 'claremont_widgets_init' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function claremont_body_classes( $classes ) {
	// Adds a class of page layout.
	if ( is_page() ) {
		if ( is_page_template( 'left-sidebar.php' ) ) {
			$classes[] = 'left-sidebar';
		} elseif ( is_page_template( 'right-sidebar.php' ) ) {
			$classes[] = 'right-sidebar';
		}
	} elseif ( is_single() || is_archive() || is_search() ) {
		$layout = get_theme_mod( 'blog_layout' );
		if ( $layout == 'left-sidebar' ) {
			$classes[] = 'left-sidebar';
		} elseif ( $layout == 'right-sidebar' ) {
			$classes[] = 'right-sidebar';
		}
	} elseif ( is_home() ) {
		$layout = get_theme_mod( 'blog_layout' );
		if ( $layout == 'left-sidebar' ) {
			$classes[] = 'left-sidebar';
		} elseif ( $layout == 'right-sidebar' ) {
			$classes[] = 'right-sidebar';
		}
	}
	
	return $classes;
}
add_filter( 'body_class', 'claremont_body_classes' );

/**
 * Enqueue scripts and styles.
 */
function claremont_enqueue_scripts() {
	// Google font
	if ( 'off' !== _x( 'on', 'Google font: on or off', 'claremont' ) ) {
		$font_style = get_theme_mod( 'font_style', 'Open Sans' );
		if ($font_style) {
			if ($font_style == "Abel" || $font_style == "Bree Serif" || $font_style == "Fjalla One") {
				$font_weight = '400';
			} elseif ($font_style == "Alegreya Sans") {
				$font_weight = '300,400,700,800';
			} elseif ($font_style == "Arimo" || $font_style == "Arvo" || $font_style == "Asap" || $font_style == "Bitter" || $font_style == "Cuprum" || $font_style == "Droid Sans" || $font_style == "Droid Serif" || $font_style == "Inconsolata" || $font_style == "Karla" || $font_style == "Lora" || $font_style == "Montserrat" || $font_style == "Noto Sans" || $font_style == "Noto Serif" || $font_style == "Passion One" || $font_style == "Play" || $font_style == "Playfair Display" || $font_style == "PT Sans" || $font_style == "PT Serif" || $font_style == "Vollkorn") {
				$font_weight = '400,700';
			} elseif ($font_style == "Cabin") {
				$font_weight = '400,500,600,700';
			} elseif ($font_style == "Catamaran" || $font_style == "Exo" || $font_style == "Exo 2" || $font_style == "Open Sans") {
				$font_weight = '300,400,600,700,800';
			} elseif ($font_style == "Crimson Text") {
				$font_weight = '400,600,700';
			} elseif ($font_style == "Dosis") {
				$font_weight = '300,400,500,600,700,800';
			} elseif ($font_style == "Hind" || $font_style == "Poppins") {
				$font_weight = '300,400,500,600,700';
			} elseif ($font_style == "Josefin Sans" || $font_style == "Signika" || $font_style == "Source Sans Pro" || $font_style == "Titillium Web") {
				$font_weight = '300,400,600,700';
			} elseif ($font_style == "Lato" || $font_style == "Merriweather" || $font_style == "Nunito" || $font_style == "Oswald" || $font_style == "Oxygen" || $font_style == "Roboto Slab" || $font_style == "Rubik" || $font_style == "Yanone Kaffeesatz") {
				$font_weight = '300,400,700';
			} elseif ($font_style == "Maven Pro" || $font_style == "Orbitron") {
				$font_weight = '400,500,700';
			} elseif ($font_style == "Merriweather Sans") {
				$font_weight = '300,400,700,800';
			} elseif ($font_style == "Muli") {
				$font_weight = '300,400';
			} elseif ($font_style == "Raleway") {
				$font_weight = '300,400,600,700,800';
			} elseif ($font_style == "Roboto" || $font_style == "Ubuntu") {
				$font_weight = '300,400,500,700';
			} else {
				$font_style = 'Open Sans';
				$font_weight = '300,400,600,700,800';
			}
			$font_url = add_query_arg( 'family', urlencode( '' . esc_html( $font_style ) . ':' . esc_html( $font_weight ) ), "//fonts.googleapis.com/css" );
		} else {
        	$font_url = add_query_arg( 'family', urlencode( 'Open Sans:300,400,600,700,800' ), "//fonts.googleapis.com/css" );
    	}
    }
    wp_enqueue_style( 'claremont-fonts', $font_url );

    // Icon Font
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/fonts/font-awesome.css' );

	// WP Dashicons stylesheet
	wp_enqueue_style( 'claremont-style', get_stylesheet_uri(), array( 'dashicons' ) );

	// Chosen Stylesheet
	$stylesheet = get_theme_mod( 'stylesheet', 'fresh' );
	if ($stylesheet == 'fresh') {
	wp_add_inline_style( 'claremont-style', claremont_custom_css() );
	} else {
		$stylesheet = esc_html($stylesheet);
	wp_enqueue_style( 'claremont-template-style', get_template_directory_uri() . '/css/'.$stylesheet.'.css' );
	wp_add_inline_style( 'claremont-template-style', claremont_custom_css() );
	}

	// Claremont script
	wp_enqueue_script( 'claremont-functions', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	do_action( 'claremont_scripts');
}
add_action( 'wp_enqueue_scripts', 'claremont_enqueue_scripts' );

/**
 * Enqueue scripts and styles for Block Editor.
 */
function claremont_enqueue_gutenberg_block_editor_assets() {
	// Google font
	if ( 'off' !== _x( 'on', 'Google font: on or off', 'claremont' ) ) {
		$font_style = get_theme_mod( 'font_style', 'Open Sans' );
		if ($font_style) {
			if ($font_style == "Abel" || $font_style == "Bree Serif" || $font_style == "Fjalla One") {
				$font_weight = '400';
			} elseif ($font_style == "Alegreya Sans") {
				$font_weight = '300,400,700,800';
			} elseif ($font_style == "Arimo" || $font_style == "Arvo" || $font_style == "Asap" || $font_style == "Bitter" || $font_style == "Cuprum" || $font_style == "Droid Sans" || $font_style == "Droid Serif" || $font_style == "Inconsolata" || $font_style == "Karla" || $font_style == "Lora" || $font_style == "Montserrat" || $font_style == "Noto Sans" || $font_style == "Noto Serif" || $font_style == "Passion One" || $font_style == "Play" || $font_style == "Playfair Display" || $font_style == "PT Sans" || $font_style == "PT Serif" || $font_style == "Vollkorn") {
				$font_weight = '400,700';
			} elseif ($font_style == "Cabin") {
				$font_weight = '400,500,600,700';
			} elseif ($font_style == "Catamaran" || $font_style == "Exo" || $font_style == "Exo 2" || $font_style == "Open Sans") {
				$font_weight = '300,400,600,700,800';
			} elseif ($font_style == "Crimson Text") {
				$font_weight = '400,600,700';
			} elseif ($font_style == "Dosis") {
				$font_weight = '300,400,500,600,700,800';
			} elseif ($font_style == "Hind" || $font_style == "Poppins") {
				$font_weight = '300,400,500,600,700';
			} elseif ($font_style == "Josefin Sans" || $font_style == "Signika" || $font_style == "Source Sans Pro" || $font_style == "Titillium Web") {
				$font_weight = '300,400,600,700';
			} elseif ($font_style == "Lato" || $font_style == "Merriweather" || $font_style == "Nunito" || $font_style == "Oswald" || $font_style == "Oxygen" || $font_style == "Roboto Slab" || $font_style == "Rubik" || $font_style == "Yanone Kaffeesatz") {
				$font_weight = '300,400,700';
			} elseif ($font_style == "Maven Pro" || $font_style == "Orbitron") {
				$font_weight = '400,500,700';
			} elseif ($font_style == "Merriweather Sans") {
				$font_weight = '300,400,700,800';
			} elseif ($font_style == "Muli") {
				$font_weight = '300,400';
			} elseif ($font_style == "Raleway") {
				$font_weight = '300,400,600,700,800';
			} elseif ($font_style == "Roboto" || $font_style == "Ubuntu") {
				$font_weight = '300,400,500,700';
			} else {
				$font_style = 'Open Sans';
				$font_weight = '300,400,600,700,800';
			}
			$font_url = add_query_arg( 'family', urlencode( '' . esc_html( $font_style ) . ':' . esc_html( $font_weight ) ), "//fonts.googleapis.com/css" );
		} else {
        	$font_url = add_query_arg( 'family', urlencode( 'Open Sans:300,400,600,700,800' ), "//fonts.googleapis.com/css" );
    	}
    }
    wp_enqueue_style( 'claremont-block-editor-fonts', $font_url );

	wp_enqueue_style( 'claremont-block-editor-style', get_template_directory_uri() . '/css/block-editor-style.css' );

	// Chosen Stylesheet
	$stylesheet = get_theme_mod( 'stylesheet', 'fresh' );
	if ($stylesheet == 'fresh') {
	} else {
		$stylesheet = esc_html($stylesheet);
		wp_enqueue_style( 'claremont-block-editor-template-style', get_template_directory_uri() . '/css/block-editor-style-'.$stylesheet.'.css' );
	}

}
add_action( 'enqueue_block_editor_assets', 'claremont_enqueue_gutenberg_block_editor_assets' );

require get_template_directory() . '/functions/claremont-customizer.php';
require get_template_directory() . '/functions/claremont-output.php';

/**
 * TGM Plugin activation.
 */
require_once get_template_directory() . '/functions/class-tgm-plugin-activation.php';
 
add_action( 'tgmpa_register', 'claremont_reg_plugin' );
function claremont_reg_plugin() {
 
    $plugins[] = array(
    		// Translators: If the plugin name in your language is the same, do not translate into your own language.
            'name'               => esc_html__( 'Meteor Slides', 'claremont' ),
            'slug'               => 'meteor-slides',
            'required'           => false,
    );

    $plugins[] = array(
    		// Translators: If the plugin name in your language is the same, do not translate into your own language.
            'name'               => esc_html__( 'Contact Form 7', 'claremont' ),
            'slug'               => 'contact-form-7',
            'required'           => false,
    );

    tgmpa( $plugins);
 
}